package SPVM::Scope::Guard::Handler;

1;

=head1 Name

SPVM::Scope::Guard::Handler - Handler of Scope::Guard

=head1 Usage
  
  use Scope::Guard::Handler;

=head1 Description

C<Scope::Guard::Handler> is an L<interface|SPVM::Document::Language/"Interface"> for the handler of L<Scope::Guard|SPVM::Scope::Guard>.

=head1 Interface Methods

=head2 Anon Method

  required method : void ();

The handler of L<Scope::Guard|SPVM::Scope::Guard>.

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License
